﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data.SQLite;
using System.Data.SQLiteManager;

namespace TestSQLiteManager
{
    class Program
    {
        static void Main(string[] args)
        {
            const string db = "test.db";
            
            /* DBファイルを作ります */
            SQLiteConnector.CreateDB(db);

            /* データベースに接続 */
            SQLiteConnector.Connect(db);

            /* テストテーブルを作成 */
            SQLiteConnector.Instance.ExecuteNonQuery("create table book(id integer primary key not null, title text, author text)"); 

            /* 忘れないように：忘れると鬼のように重くなります */
            SQLiteConnector.Instance.TransactionStart();
            
            for (int i = 0; i < 10000; i++)
            {
                /* 試しに、10000件ほどデータを入れてみます */
                /* 興味がある方は、前後の明示的なトランザクションを除けてもやってみてください */
                int n = SQLiteConnector.Instance.ExecuteInsert("insert into book values(null,?,?)", "title" + i % 100, "author" + i);
                Console.WriteLine(n);
            }
            /* 忘れないように */
            SQLiteConnector.Instance.TransactionCommit();

            /* 単体のinsertなどであれば、わざわざトランザクションを明示的に行わなくても、速度的には同じだと思われます */
            SQLiteConnector.Instance.ExecuteNonQuery("insert into book(title, author) values(?,?)", "ttttt", "bbbbb");

            /* SELECTはこのように受け取ります */
            Result result = SQLiteConnector.Instance.ExecuteReader("select book.* from book where title = ?", "title3");

            /* 列名はこのように取得できます */
            Console.WriteLine("{0}\t{1}\t{2}", result.ColumnName[0], result.ColumnName[1], result.ColumnName[2]);

            for (int i = 0; i < result.Length; i++)
            {
                /* このように、列名を入れることで直感的に取得できます。 */
                Console.WriteLine("{0}\t{1}\t{2}", result[i]["id"], result[i]["title"], result[i]["author"]);
            }

            /* 開いたものは閉じましょう */
            SQLiteConnector.Disconnect();

            Console.ReadLine();
        }
    }
}
